==> jc-1.4.0.tar.gz: javax/swing/JList__24ListListener.h <==
// class javax.swing.JList$ListListener

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 9600e3d783f70ee javax_swing_JList__24ListListener

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_JList__24ListListener_H_
#define _JC_javax_swing_JList__24ListListener_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_JList$object;
struct _jc_javax_swing_JList__241$object;
struct _jc_javax_swing_event_ListDataEvent$object;
struct _jc_javax_swing_event_ListSelectionEvent$object;

// Typedefs
typedef struct _jc_javax_swing_JList__24ListListener$sub_refs	_jc_javax_swing_JList__24ListListener$sub_refs;
typedef struct _jc_javax_swing_JList__24ListListener$sub_nonrefs	_jc_javax_swing_JList__24ListListener$sub_nonrefs;
typedef struct _jc_javax_swing_JList__24ListListener$refs	_jc_javax_swing_JList__24ListListener$refs;
typedef struct _jc_javax_swing_JList__24ListListener$nonrefs	_jc_javax_swing_JList__24ListListener$nonrefs;
typedef struct _jc_javax_swing_JList__24ListListener$object	_jc_javax_swing_JList__24ListListener$object;

typedef const struct _jc_javax_swing_JList__24ListListener$vmethods	_jc_javax_swing_JList__24ListListener$vmethods;
typedef const struct _jc_javax_swing_JList__24ListListener$vtable	_jc_javax_swing_JList__24ListListener$vtable;
typedef const struct _jc_javax_swing_JList__24ListListener$vtype	_jc_javax_swing_JList__24ListListener$vtype;

// Constructors
extern void _jc_javax_swing_JList__24ListListener$method$_init$66158a66be23efc0(_jc_env *, struct _jc_javax_swing_JList__24ListListener$object *, struct _jc_javax_swing_JList$object *);
extern void _jc_javax_swing_JList__24ListListener$method$_init$ee3bf656901fca8b(_jc_env *, struct _jc_javax_swing_JList__24ListListener$object *, struct _jc_javax_swing_JList$object *, struct _jc_javax_swing_JList__241$object *);

// Virtual methods
extern void _jc_javax_swing_JList__24ListListener$method$contentsChanged$c5b5afa57c7efdab(_jc_env *, struct _jc_javax_swing_JList__24ListListener$object *, struct _jc_javax_swing_event_ListDataEvent$object *);
extern void _jc_javax_swing_JList__24ListListener$method$intervalAdded$c10548227f018e1d(_jc_env *, struct _jc_javax_swing_JList__24ListListener$object *, struct _jc_javax_swing_event_ListDataEvent$object *);
extern void _jc_javax_swing_JList__24ListListener$method$intervalRemoved$5c70087e83dde061(_jc_env *, struct _jc_javax_swing_JList__24ListListener$object *, struct _jc_javax_swing_event_ListDataEvent$object *);
extern void _jc_javax_swing_JList__24ListListener$method$valueChanged$f360df5a43a62b7d(_jc_env *, struct _jc_javax_swing_JList__24ListListener$object *, struct _jc_javax_swing_event_ListSelectionEvent$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_JList__24ListListener$method_info$contentsChanged$c5b5afa57c7efdab;
extern _jc_method _jc_javax_swing_JList__24ListListener$method_info$intervalAdded$c10548227f018e1d;
extern _jc_method _jc_javax_swing_JList__24ListListener$method_info$intervalRemoved$5c70087e83dde061;
extern _jc_method _jc_javax_swing_JList__24ListListener$method_info$valueChanged$f360df5a43a62b7d;

// Virtual methods structure
struct _jc_javax_swing_JList__24ListListener$vmethods {
	void	(*contentsChanged$c5b5afa57c7efdab)(_jc_env *, struct _jc_javax_swing_JList__24ListListener$object *, struct _jc_javax_swing_event_ListDataEvent$object *);
	void	(*intervalAdded$c10548227f018e1d)(_jc_env *, struct _jc_javax_swing_JList__24ListListener$object *, struct _jc_javax_swing_event_ListDataEvent$object *);
	void	(*intervalRemoved$5c70087e83dde061)(_jc_env *, struct _jc_javax_swing_JList__24ListListener$object *, struct _jc_javax_swing_event_ListDataEvent$object *);
	void	(*valueChanged$f360df5a43a62b7d)(_jc_env *, struct _jc_javax_swing_JList__24ListListener$object *, struct _jc_javax_swing_event_ListSelectionEvent$object *);
};

// Vtable
struct _jc_javax_swing_JList__24ListListener$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_JList__24ListListener$vmethods	javax_swing_JList__24ListListener;
};

// Vtype
struct _jc_javax_swing_JList__24ListListener$vtype {
	_jc_type			type;
	_jc_javax_swing_JList__24ListListener$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_JList__24ListListener$sub_refs {
	struct _jc_javax_swing_JList$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_JList__24ListListener$refs {
    _jc_javax_swing_JList__24ListListener$sub_refs	javax_swing_JList__24ListListener;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_JList__24ListListener$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_JList__24ListListener$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_JList__24ListListener$sub_nonrefs	javax_swing_JList__24ListListener;
};

// Object instance structure
struct _jc_javax_swing_JList__24ListListener$object {
	_jc_javax_swing_JList__24ListListener$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_JList__24ListListener$vtype	*vtype;
	_jc_javax_swing_JList__24ListListener$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_JList__24ListListener$vtype _jc_javax_swing_JList__24ListListener$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_JList__24ListListener, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_JList__24ListListener$class_object;

#endif	/* _JC_javax_swing_JList__24ListListener_H_ */

==> jc-1.4.5.tar.gz: javax/swing/JList__24ListListener.h <==
// class javax.swing.JList$ListListener

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 9600e3d783f70ee javax_swing_JList__24ListListener

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_JList__24ListListener_H_
#define _JC_javax_swing_JList__24ListListener_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_JList$object;
struct _jc_javax_swing_JList__241$object;
struct _jc_javax_swing_event_ListDataEvent$object;
struct _jc_javax_swing_event_ListSelectionEvent$object;

// Typedefs
typedef struct _jc_javax_swing_JList__24ListListener$sub_refs	_jc_javax_swing_JList__24ListListener$sub_refs;
typedef struct _jc_javax_swing_JList__24ListListener$sub_nonrefs	_jc_javax_swing_JList__24ListListener$sub_nonrefs;
typedef struct _jc_javax_swing_JList__24ListListener$refs	_jc_javax_swing_JList__24ListListener$refs;
typedef struct _jc_javax_swing_JList__24ListListener$nonrefs	_jc_javax_swing_JList__24ListListener$nonrefs;
typedef struct _jc_javax_swing_JList__24ListListener$object	_jc_javax_swing_JList__24ListListener$object;

typedef const struct _jc_javax_swing_JList__24ListListener$vmethods	_jc_javax_swing_JList__24ListListener$vmethods;
typedef const struct _jc_javax_swing_JList__24ListListener$vtable	_jc_javax_swing_JList__24ListListener$vtable;
typedef const struct _jc_javax_swing_JList__24ListListener$vtype	_jc_javax_swing_JList__24ListListener$vtype;

// Constructors
extern void _jc_javax_swing_JList__24ListListener$method$_init$66158a66be23efc0(_jc_env *, struct _jc_javax_swing_JList__24ListListener$object *, struct _jc_javax_swing_JList$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_JList__24ListListener$method$_init$ee3bf656901fca8b(_jc_env *, struct _jc_javax_swing_JList__24ListListener$object *, struct _jc_javax_swing_JList$object *, struct _jc_javax_swing_JList__241$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_javax_swing_JList__24ListListener$method$contentsChanged$c5b5afa57c7efdab(_jc_env *, struct _jc_javax_swing_JList__24ListListener$object *, struct _jc_javax_swing_event_ListDataEvent$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_JList__24ListListener$method$intervalAdded$c10548227f018e1d(_jc_env *, struct _jc_javax_swing_JList__24ListListener$object *, struct _jc_javax_swing_event_ListDataEvent$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_JList__24ListListener$method$intervalRemoved$5c70087e83dde061(_jc_env *, struct _jc_javax_swing_JList__24ListListener$object *, struct _jc_javax_swing_event_ListDataEvent$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_JList__24ListListener$method$valueChanged$f360df5a43a62b7d(_jc_env *, struct _jc_javax_swing_JList__24ListListener$object *, struct _jc_javax_swing_event_ListSelectionEvent$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_JList__24ListListener$method_info$contentsChanged$c5b5afa57c7efdab;
extern _jc_method _jc_javax_swing_JList__24ListListener$method_info$intervalAdded$c10548227f018e1d;
extern _jc_method _jc_javax_swing_JList__24ListListener$method_info$intervalRemoved$5c70087e83dde061;
extern _jc_method _jc_javax_swing_JList__24ListListener$method_info$valueChanged$f360df5a43a62b7d;

// Virtual methods structure
struct _jc_javax_swing_JList__24ListListener$vmethods {
	void	(*contentsChanged$c5b5afa57c7efdab)(_jc_env *, struct _jc_javax_swing_JList__24ListListener$object *, struct _jc_javax_swing_event_ListDataEvent$object *) _JC_JCNI_ATTR;
	void	(*intervalAdded$c10548227f018e1d)(_jc_env *, struct _jc_javax_swing_JList__24ListListener$object *, struct _jc_javax_swing_event_ListDataEvent$object *) _JC_JCNI_ATTR;
	void	(*intervalRemoved$5c70087e83dde061)(_jc_env *, struct _jc_javax_swing_JList__24ListListener$object *, struct _jc_javax_swing_event_ListDataEvent$object *) _JC_JCNI_ATTR;
	void	(*valueChanged$f360df5a43a62b7d)(_jc_env *, struct _jc_javax_swing_JList__24ListListener$object *, struct _jc_javax_swing_event_ListSelectionEvent$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_JList__24ListListener$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_JList__24ListListener$vmethods	javax_swing_JList__24ListListener;
};

// Vtype
struct _jc_javax_swing_JList__24ListListener$vtype {
	_jc_type			type;
	_jc_javax_swing_JList__24ListListener$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_JList__24ListListener$sub_refs {
	struct _jc_javax_swing_JList$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_JList__24ListListener$refs {
    _jc_javax_swing_JList__24ListListener$sub_refs	javax_swing_JList__24ListListener;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_JList__24ListListener$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_JList__24ListListener$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_JList__24ListListener$sub_nonrefs	javax_swing_JList__24ListListener;
};

// Object instance structure
struct _jc_javax_swing_JList__24ListListener$object {
	_jc_javax_swing_JList__24ListListener$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_JList__24ListListener$vtype	*vtype;
	_jc_javax_swing_JList__24ListListener$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_JList__24ListListener$vtype _jc_javax_swing_JList__24ListListener$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_JList__24ListListener, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_JList__24ListListener$class_object;

#endif	/* _JC_javax_swing_JList__24ListListener_H_ */
